@@ -1,7 +1,9 @@
 import re
 import datetime
 import sys
+import random
 import os
+from turtle import color
 import pandas as pd
 from pandas import DataFrame
 import matplotlib.pyplot as plt
@@ -10,12 +12,17 @@ import mplfinance as mpf
 from matplotlib.ticker import Formatter
 import numpy as np
 import json
+import efinance as ef
+from datetime import datetime
+from .zhangting import ZhangTing
 sys.path.append("..")
 sys.path.append("../..")
 
-class DrawTick:
+class DrawingBoard:
     time_map_x_=None
     def __init__(self):
+        self.zhangting_ = ZhangTing()
+
         self.time_map_x_= {\
 915:0, 916:1, 917:2, 918:3, 919:4, 920:5, 921:6, 922:7, 923:8, 924:9, 925:10, 930:10,
 931:11, 932:12, 933:13, 934:14, 935:15, 936:16, 937:17, 938:18, 939:19, 940:20,
@@ -56,30 +63,48 @@ class DrawTick:
         file=open(tick_data_path,'r')
         jsondict=json.load(file)
         pricelist=jsondict.get('price')#价格
-        amountlist=jsondict.get('amount')#金额
+        #amountlist=jsondict.get('amount')#金额
         timelist=jsondict.get('time')#时间
         for index in range(0, len(pricelist)):
             #timelist[index]=float(timelist[index])
             pricelist[index]=float(pricelist[index])
-            amountlist[index]=float(amountlist[index])
+            #amountlist[index]=float(amountlist[index])
         self.pain_df_=pd.DataFrame(jsondict)
-        self.draw()
+        self.Draw()
+
+    def DrawDict(self, code, jsondict):
+        zhangting_data = self.zhangting_.Get(20220720, code)
+        open_price=zhangting_data['open_price_']
+        top_price=zhangting_data['top_price_']
+        bottom_price=zhangting_data['bottom_price_']
+        todaydate = datetime.today().strftime('%Y%m%d')
+        self.Set(code, todaydate, open_price, top_price, bottom_price)
+        #def Set(self, code, trade_date, open_price, zhangting_price):
+        pricelist=jsondict.get('price')#价格
+        #amountlist=jsondict.get('amount')#金额
+        timelist=jsondict.get('time')#时间
+        for index in range(0, len(pricelist)):
+            #timelist[index]=float(timelist[index])
+            pricelist[index]=float(pricelist[index])
+            #amountlist[index]=float(amountlist[index])
+        self.pain_df_=pd.DataFrame(jsondict)
+        self.Draw()
 
     #time->09:30:49 
     def ConvertTimeToX(self, time_str):
         time_list=time_str.split(":")
-        time_int=int(time_list[0])*10000+int(time_list[1])*100+int(time_list[2])
-        print("time_int:", time_int)
+        time_int=int(time_list[0])*100+int(time_list[1])
+        #print("time_int:", time_int)
         return self.time_map_x_[time_int]
 
-    def Set(self, code, trade_date, open_price, zhangting_price):
+    def Set(self, code, trade_date, open_price, zhangting_price, bottom_price):
         self.code_=code
         self.trade_date_=trade_date
-        self.y_limit_high_=zhangting_price
-        self.y_zero_price_ = open_price
-        self.y_limit_low_=zhangting_price*0.8
+        self.y_limit_high_= float(zhangting_price)
+        self.y_zero_price_ = float(open_price)
+        self.y_limit_low_= float(bottom_price)
         self.image_name_ =str(trade_date)+"_"+str(code)+".png"
-        self.image_path_='./TickImg/'+self.image_name_
+        self.image_path_='D:/stock/TickImg/'+self.image_name_
         self.yticks_price_=[]
         for i in range(0, len(self.yticks_price_names_)):
             weight=float(i-10)/100
@@ -87,24 +112,39 @@ class DrawTick:
         self.yticks_price_names_=['-10%','-9%','-8%','-7%','-6%','-5%','-4%','-3%','-2%','-1%','0','1%','2%','3%','4%','5%','6%','7%','8%','9%','10%']
         return self
 
-    def AddPoint(self, image, time_str, price, money):
+    def AddPoint(self, image, time_str, price, money, option, count):
         x=self.ConvertTimeToX(time_str)
         y=float(price)
-        image.scatter(x, y, s=100)
-        image.annotate(money, xy=(x, y), fontsize=20, xycoords="data")
+        color='r'
+        if option == "主动买入":
+            image.scatter(x, y, s=100, c = 'r')
+            color='r'
+        else:
+            image.scatter(x, y, s=100, c = 'b')
+            color='b'
+        image.annotate(
+            money, 
+            xy=(x, y), 
+            fontsize=20, 
+            xytext=(x+x*count/50, y+y*count/200),
+            color=color,
+            horizontalalignment='right', 
+            verticalalignment='top',
+            arrowprops=dict(arrowstyle='-', connectionstyle="arc3", color=color),
+            xycoords="data")
 
-    def draw(self):
+    def Draw(self):
         self.pain_df_['time']=pd.to_datetime(self.pain_df_['time'], format="%H%M%S")
         #self.pain_df_['time']=tradedate + ' '+self.pain_df_['time']
         self.pain_df_ = self.pain_df_.set_index('time')
 
         price_df=self.pain_df_['price'].resample('1min').ohlc().dropna()
 
-        amounts=self.pain_df_['amount'].resample('1min').sum().dropna()
-        amount_df=pd.DataFrame(amounts, columns=['amount'])
+        #amounts=self.pain_df_['amount'].resample('1min').sum().dropna()
+        #amount_df=pd.DataFrame(amounts, columns=['amount'])
 
-        resample_df=price_df.merge(amount_df, left_index=True, right_index=True)
-        resample_df=resample_df.reset_index()
+        #resample_df=price_df.merge(amount_df, left_index=True, right_index=True)
+        resample_df=price_df.reset_index()
         #resample_df.to_csv('./TickImg/'+str(code)+'.'+tradedate+'.min.csv')
 
         #matplotlib的date2num将日期转换为浮点数，整数部分区分日期，小数区分小时和分钟
@@ -113,22 +153,23 @@ class DrawTick:
 
         resample_df['time']=resample_df['time'].apply(lambda x:dates.date2num(x)*1440)
         #print(resample_df['time'])
-        resample_df['MA5']=resample_df['close'].rolling(window=5).mean()
+        #resample_df['MA5']=resample_df['close'].rolling(window=5).mean()
 
-        plt.figure(figsize=(20,20))
+        plt.figure(figsize=(50,50))
         #a1=plt.subplot(2,1,1)
         plt.grid(color='gray',linestyle='-')
         plt.plot( resample_df['close'].tolist(), c='r')
-        plt.plot( resample_df['MA5'].tolist(), c='y')
+        #plt.plot( resample_df['MA5'].tolist(), c='y')
         #plt.ylim(self.y_limit_low_, self.y_limit_high_)
         plt.ylim(self.y_zero_price_*0.9, self.y_limit_high_)
         plt.xticks(self.xticks_times_, self.xticks_time_names_, size=15, rotation=40)
         plt.yticks(self.yticks_price_, self.yticks_price_names_, size=15, rotation=40)
         plt.title(self.image_name_)
         print(self.image_path_)
-        plt.savefig(self.image_path_)
+        #plt.savefig(self.image_path_)
+        self.plt=plt
 
-def Test():
-    draw_handle=DrawTick()
-    draw_handle.Set('123456', '20220715', 17, 19).DrawJson(None)
-    draw_handle.Set('1234567', '20220716', 17, 20).DrawJson(None)
\ No newline at end of file
+#def Test():
+#    draw_handle=DrawingBoard()
+#    draw_handle.Set('123456', '20220715', 17, 19).DrawJson(None)
+#    draw_handle.Set('1234567', '20220716', 17, 20).DrawJson(None)
\ No newline at end of file
